use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.007005
use Test::Spelling 0.12;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( bin lib ) );
__DATA__
AE
AO
API
AQ
Abidjan
Accra
Adak
Adelaide
Africa
Aland
Alders
Alexey
Alfie
Algiers
Almaty
America
Amman
Amsterdam
Anadyr
Anchorage
Andorra
Android
Antarctica
Apia
Aqtau
Aqtobe
Araguaina
Argentina
Ashgabat
Asia
Astrakhan
Asuncion
Athens
Atikokan
Atlantic
Atyrau
Auckland
Australia
Azores
BD
BG
BH
BJ
BN
BQ
BT
BW
BZ
Baghdad
Bahia
Bahia_Banderas
Baku
Bangkok
Barbados
Barnaul
Barthelemy
Beirut
Belem
Belgrade
Belize
Berlin
Bermuda
Beulah
Bishkek
Bissau
Blanc_Sablon
Boa_Vista
Bogota
Boise
Bolivarian
Bonaire
Bougainville
Brisbane
Broken_Hill
Bron
Brunei
Brussels
Bucharest
Budapest
Buenos_Aires
Burkina
CET
CN
CPAN
CST6CDT
CX
CY
Cabo
Caicos
Cairo
Cambridge_Bay
Campo_Grande
Canary
Cancun
Cape_Verde
Caracas
Casablanca
Casey
Catalog
Catamarca
Cayenne
Center
Ceuta
Chagos
Change
Chatham
Chicago
Chihuahua
Chisinau
Chita
Choibalsan
Christmas
Chuuk
Cocos
Colombo
Copenhagen
Cordoba
Costa
Costa_Rica
Creston
Cuiaba
Cunha
Curacao
Currie
Czechia
DK
DM
DROLSKY
DROLSKY's
Daisuke
Damascus
Danmarkshavn
Darussalam
Darwin
DateTime
Dave
David
Davis
Dawson
Dawson_Creek
Denver
Detroit
Dhaka
Dili
Dubai
Dublin
DumontDUrville
Dushanbe
EE
EET
EG
EST
EST5EDT
Easter
Edmonton
Efate
Eirunepe
El
El_Aaiun
El_Salvador
Enderbury
Etheridge
Eucla
Europe
Eustatius
FI
FJ
FK
FO
Fakaofo
Famagusta
Faroe
Faso
Fiji
Floating
Fort_Nelson
Fortaleza
FromEnv
Funafuti
Futuna
GF
GG
GH
GL
GN
GQ
GW
GY
Galapagos
Gambier
Gaza
Gibraltar
Glace_Bay
Godthab
Gondwana
Goose_Bay
Grand_Turk
Guadalcanal
Guam
Guatemala
Guayaquil
Guyana
HK
HN
HPUX
HST
HU
Halifax
Havana
Hebron
Helsinki
Hermosillo
Ho_Chi_Minh
Hobart
Hoblitt
Hong
Hong_Kong
Honolulu
Hovd
IM
Iain
Indian
Indiana
Indianapolis
Inuvik
Iqaluit
Irkutsk
Istanbul
JE
JM
Jakarta
Jakub
Jamahiriya
Jamaica
Jayapura
Jerusalem
Johannesburg
John
Joshua
Juba
Jujuy
Juneau
KE
KH
KI
KZ
Kabul
Kaliningrad
Kamchatka
Karachi
Karen
Kathmandu
Kentucky
Kerguelen
Khandyga
Khartoum
Kiev
Kiritimati
Kirov
Kitts
Knox
Kolkata
Kosrae
Krasnoyarsk
Kuala_Lumpur
Kuching
Kwajalein
LK
LV
LY
La_Paz
La_Rioja
Lagos
Lanka
Leone
Leste
Lima
Lindeman
Lisbon
Local
London
Lord_Howe
Los_Angeles
Louisville
Luxembourg
MET
MF
MH
MQ
MST
MST7MDT
MX
MZ
Maarten
Macau
Maceio
Macquarie
Madeira
Madrid
Magadan
Mahe
Majuro
Makassar
Maki
Maldives
Malta
Malvinas
Managua
Manaus
Manila
Maputo
Marengo
Marino
Marquesas
Martinique
Matamoros
Mauritius
Mawson
Mayen
Mayotte
Mazatlan
Melbourne
Mendoza
Menominee
Merida
Metlakatla
Mexico_City
Millenium
Minsk
Miquelon
Molchanov
Monaco
Moncton
Monrovia
Monterrey
Montevideo
Monticello
Moscow
NG
NL
Nairobi
Nassau
Nauru
Ndjamena
New_Salem
New_York
Nicosia
Nipigon
Niue
Nome
Norfolk
Noronha
North_Dakota
Noumea
Novokuznetsk
Novosibirsk
Observance
OffsetOnly
Ojinaga
Olaf
OlsonDB
Omsk
Oral
Oslo
PN
PST8PDT
PY
Pacific
Pago_Pago
Palau
Palmer
Panama
Pangnirtung
Papua
Paramaribo
Paris
PayPal
Perth
Peter
Petersburg
Phoenix
Pinkowitz
Pitcairn
Plurinational
Pohnpei
Pontianak
Port_Moresby
Port_au_Prince
Port_of_Spain
Porto_Velho
Prague
Puerto
Puerto_Rico
Punta_Arenas
Pyongyang
QA
Qatar
Qyzylorda
RO
RW
Rabbitson
Rainy_River
Rankin_Inlet
Rarotonga
Rata
Recife
Regina
Resolute
Reunion
Reykjavik
Rica
Riga
Rio_Branco
Rio_Gallegos
Riyadh
Rolsky
Rolsky's
Rome
Rothera
Rule
SG
SL
SV
SX
SY
SZ
Saba
Sakhalin
Salta
Samara
Samarkand
San_Juan
San_Luis
Santarem
Santiago
Santo_Domingo
Sao
Sao_Paulo
Sao_Tome
Saratov
Scoresbysund
Seoul
Shanghai
Simferopol
Singapore
Sint
Sitka
Sofia
South_Georgia
Srednekolymsk
Sri
St_Johns
Stanley
Starman
Stockholm
Storable
Subclass
Subclasses
Swift_Current
Sydney
Syowa
TF
TG
TJ
TK
TT
TW
TZ
Tahiti
Taipei
Tallinn
Tarawa
Tashkent
Tbilisi
Tegucigalpa
Tehran
Tell_City
Thimphu
Thule
Thunder_Bay
Tijuana
TimeZone
Timor
Tirane
Tokelau
Tokyo
Tom
Tomsk
Tongatapu
Toronto
Tripoli
Troll
Truskett
Tucuman
Tunis
UA
UG
UIs
UTC
UY
UZ
Ulaanbaatar
Ulyanovsk
Unix
Urumqi
Ushuaia
Ust_Nera
Uzhgorod
VC
VE
VMS
VN
VU
Vancouver
Vevay
Vienna
Viet
Vilnius
Vincennes
Vladivostok
Volgograd
Vostok
WET
WF
WS
Wake
Wallis
Warsaw
Whitehorse
Wilk
Winamac
Windhoek
Winnipeg
Wyant
XP
Yakutat
Yakutsk
Yangon
Yekaterinburg
Yellowknife
Yerevan
ZA
ZM
ZW
Zaporozhye
Zealand
Zone
Zurich
alexey
alfiej
autarch
brong
d'Ivoire
da
datetime
dave
deceased
dmaki
drolsky
env
ether
jhoblitt
jwilk
karupa
karupanerura
lib
olaf
pre
ribasushi
subclasses
timezones
versa
wyant
